import { select, json, geoPath, geoAlbersUsa } from 'd3';
import { feature } from 'topojson';

// Selects the SVG from the HTML.
const svg = select('svg'), width=+svg.attr("width"),
      height = +svg.attr("height");

// Create a new geoNaturalEarth1() object for generating and projecting paths.

// Map and projection
var projection = d3.geoMercator()
    .center([2, 47])                // GPS of location to zoom on
    .scale(980)                       // This is like the zoom
    .translate([ width/2, height/2 ]);


// Fetches the data from the end point and then formats it project on the canvas.
json('https://cdn.jsdelivr.net/npm/world-atlas@2/countries-110m.json')
  .then(data => {
  	// Extracts all the countries in the world.
    const countries = feature(data, data.objects.countries);
  	// Extracts USA from the countries list.
  	const features = countries.features.filter(el => el.properties.name === 'France');
  	// Passes the extracted countries as data for generating the paths on the canvas  
  		// Draw the map
    svg.append("g")
        .selectAll("path")
        .data(features)
        .enter()
        .append("path")
          .attr("fill", "grey")
          .attr("d", d3.geoPath()
              .projection(projection)
          ).style("stroke", "none")
  });